@@ -54,6 +54,9 @@ def api_request( method, path, json_data = None, data = None, query_string = Non
 	"""
 		Issue a request to the API server for the account.
 	"""
+	# allow config to override (for local testing)
+	endpoint = config.get( 'api_endpoint', api_endpoint )
+	
 	path = "/{}/{}".format( config['access']['account'], path )
 	
 	if headers == None:
@@ -69,7 +72,7 @@ def api_request( method, path, json_data = None, data = None, query_string = Non
 			data = fp.read()
 
 	if verbose:
-		log( '{} {} {}'.format( method, api_endpoint + path, str(query_string) ) )
+		log( '{} {} {}'.format( method, endpoint + path, str(query_string) ) )
 		
 	if show_curl:
 		if query_string != None:
@@ -83,7 +86,7 @@ def api_request( method, path, json_data = None, data = None, query_string = Non
 			
 		cmd = "curl -X {method} {url} --user {user} {headers}".format(
 			method = method,
-			url = escape_cli( api_endpoint + path + qs ),
+			url = escape_cli(endpoint + path + qs ),
 			user = escape_cli( config['access']['user'] + ':' + config['access']['password'] ),
 			headers = " ".join( [ '-H ' + escape_cli('{}: {}'.format( k, v )) for k, v in headers.iteritems() ] ),
 		) 
@@ -95,11 +98,11 @@ def api_request( method, path, json_data = None, data = None, query_string = Non
 			
 	headers['Authorization'] = 'Basic ' + base64.b64encode( "{}:{}".format(
 		config['access']['user'], config['access']['password'] ) )
-	resp = requests.request( method, api_endpoint + path, headers = headers, data = data,
+	resp = requests.request( method, endpoint + path, headers = headers, data = data,
 		params = query_string )
 	
 	jdata = None
-	if resp.headers['Content-Type'] == 'application/json':
+	if resp.headers.get( 'Content-Type', None ) == 'application/json':
 		jdata = resp.json()
 		
 	if resp.status_code != 200:
